# Contributor resources

## Contributing Code

**Is this your first contribution?**
Please take a look at these resources to learn about git and pull requests (don't
hesitate to ask questions:

* [How to Contribute to Open Source](https://opensource.guide/how-to-contribute/).
* Aaron Meurer's [tutorial on the git workflow](https://www.asmeurer.com/git-workflow/)
* [How to Contribute to an Open Source Project on GitHub](https://egghead.io/courses/how-to-contribute-to-an-open-source-project-on-github)

If you're new to working with git, GitHub, and the Unix Shell, we recommend
starting with the [Software Carpentry](https://software-carpentry.org/) lessons,
which are available in English and Spanish:

* [Version Control with Git](https://swcarpentry.github.io/git-novice/) / spanish: [Control de
versiones con Git](https://swcarpentry.github.io/git-novice-es/)
* [The Unix Shell](https://swcarpentry.github.io/shell-novice/) / spanish:
[La Terminal de Unix](https://swcarpentry.github.io/shell-novice-es/)

## Additional contribution resources
For more information on contributing to open source projects, checkout:

*  [GitHub's contribution guide](https://docs.github.com/en)
is a great starting point if you are new to version control.
* The [Zen of Scientific Software Maintenance](https://jrleeman.github.io/ScientificSoftwareMaintenance/)
